@@ -1,6 +1,9 @@
 `meandist` <-
     function(dist, grouping, ...)
 {
+    ## check that 'dist' are dissimilarities (non-negative)
+    if (any(dist < -sqrt(.Machine$double.eps)))
+        warning("some dissimilarities are negative -- is this intentional?")
     ## merge levels so that lower is always first (filling lower triangle)
     mergenames <- function(X, Y, ...) {
         xy <- cbind(X, Y)
